@@ -3,7 +3,7 @@
 
 """
 This example runs on PyPortal, or any Circuit Python device
-with a built-in screen that is at least 320x240 pixels.
+with a built-in screen.
 
 It will use adafruit_bitmap_font to load a font and fill a
 bitmap with pixels matching glyphs from a given String
@@ -14,7 +14,7 @@ import board
 import displayio
 from adafruit_bitmap_font import bitmap_font
 
-# use built in display (PyPortal, PyGamer, PyBadge, CLUE, etc.)
+# use built in display (MagTag, PyPortal, PyGamer, PyBadge, CLUE, etc.)
 # see guide for setting up external displays (TFT / OLED breakouts, RGB matrices, etc.)
 # https://learn.adafruit.com/circuitpython-display-support-using-displayio/display-and-display-bus
 display = board.DISPLAY
@@ -25,7 +25,7 @@ font_file = "fonts/LeagueSpartan-Bold-16.bdf"
 
 font = bitmap_font.load_font(font_file)
 
-bitmap = displayio.Bitmap(320, 240, 2)
+bitmap = displayio.Bitmap(display.width, display.height, 2)
 
 palette = displayio.Palette(2)
 
